@@ -1,7 +1,8 @@
 package Path::Class;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 @ISA = qw(Exporter);
+@EXPORT    = qw(file dir);
 @EXPORT_OK = qw(file dir foreign_file foreign_dir);
 
 use strict;
@@ -24,17 +25,17 @@ Path::Class - Cross-platform path specification manipulation
 
 =head1 SYNOPSIS
 
-  use Path::Class qw(file dir);  # Export a couple of short constructors
+  use Path::Class;
   
   my $dir  = dir('foo', 'bar');       # Path::Class::Dir object
   my $file = file('bob', 'file.txt'); # Path::Class::File object
   
+  # Stringifies to 'foo/bar' on Unix, 'foo\bar' on Windows, etc.
+  print "dir: $dir\n";
+  
   # Stringifies to 'bob/file.txt' on Unix, 'bob\file.txt' on Windows
   print "file: $file\n";
   
-  # Stringifies to 'foo/bar' on Unix, 'foo\bar' on Windows
-  print "dir: $dir\n";
-  
   my $subdir  = $dir->subdir('baz');  # foo/bar/baz
   my $parent  = $subdir->parent;      # foo/bar
   my $parent2 = $parent->parent;      # foo
@@ -46,24 +47,37 @@ Path::Class - Cross-platform path specification manipulation
   my $file = foreign_file('Mac', ':foo:file.txt');
   print $file->dir;                   # :foo:
   print $file->as_foreign('Win32');   # foo\file.txt
+  
+  # Interact with the underlying filesystem:
+  
+  # $dir_handle is an IO::Dir object
+  my $dir_handle = $dir->open or die "Can't read $dir: $!";
+  
+  # $file_handle is an IO::File object
+  my $file_handle = $file->open($mode) or die "Can't read $file: $!";
 
 =head1 DESCRIPTION
 
-The well-known module C<File::Spec> allows Perl programmers to
-manipulate file and directory specifications (strings describing their
-locations, like C<'/home/ken/foo.txt'> or C<'C:\Windows\Foo.txt'>) in
-a cross-platform manner, but it's sort of awkward to use well, so
-people sometimes avoid it.
+C<Path::Class> is a module for manipulation of file and directory
+specifications (strings describing their locations, like
+C<'/home/ken/foo.txt'> or C<'C:\Windows\Foo.txt'>) in a cross-platform
+manner.  It supports pretty much every platform Perl runs on,
+including Unix, Windows, Mac, VMS, Epoc, Cygwin, OS/2, and NetWare.
 
-C<Path::Class> provides a nicer interface (nicer in my opinion,
-anyway) to the C<File::Spec> functionality.  C<File::Spec> has an
-object-oriented interface, but the OO-ness doesn't actually buy you
-anything.  All it does is give you a really long name for some things
-that are essentially function calls (not very helpful), and lets you
-avoid polluting your namespace with function names (somewhat helpful).
+The well-known module C<File::Spec> also provides this service, but
+it's sort of awkward to use well, so people sometimes avoid it, or use
+it in a way that won't actually work properly on platforms
+significantly different than the ones they've tested their code on.
 
-C<Path::Class> actually gets some mileage out of its class hierarchy.
-It has a class for files and a class for directories, and methods that
+In fact, C<Path::Class> uses C<File::Spec> internally, wrapping all
+the unsightly details so you can concentrate on your application code.
+Whereas C<File::Spec> provides functions for some common path
+manipulations, C<Path::Class> provides an object-oriented model of the
+world of path specifications and their underlying semantics.
+C<File::Spec> doesn't create any objects, and its classes represent
+the different ways in which paths must be manipulated on various
+platforms (not a very intuitive concept).  C<Path::Class> creates
+objects representing files and directories, and provides methods that
 relate them to each other.  For instance, the following C<File::Spec>
 code:
 
@@ -79,9 +93,8 @@ or even as
 
  my $absolute = file( @dirs, $file )->is_absolute;
 
-if you're willing to export the C<file> function into your namespace.
-Similar readability improvements happen all over the place when using
-C<Path::Class>.
+Similar readability improvements should happen all over the place when
+using C<Path::Class>.
 
 Using C<Path::Class> can help solve real problems in your code too -
 for instance, how many people actually take the "volume" (like C<C:>
@@ -95,7 +108,7 @@ modules' documentation for more details about how to use them.
 
 =head2 EXPORT
 
-The following functions can be exported upon request:
+The following functions are exported by default.
 
 =over 4
 
@@ -107,6 +120,15 @@ A synonym for C<< Path::Class::File->new >>.
 
 A synonym for C<< Path::Class::Dir->new >>.
 
+=back
+
+If you would like to prevent their export, you may explicitly pass an
+empty list to perl's C<use>, i.e. C<use Module::Build ()>.
+
+The following are exported only on demand.
+
+=over 4
+
 =item foreign_file
 
 A synonym for C<< Path::Class::File->new_foreign >>.
