@@ -5,6 +5,9 @@ use Path::Class::Dir;
 use Path::Class::Entity;
 use base qw(Path::Class::Entity);
 
+use IO::File ();
+use File::stat ();
+
 sub new {
   my $self = shift->SUPER::new;
   my $file = pop();
@@ -34,7 +37,7 @@ sub as_foreign {
 sub stringify {
   my $self = shift;
   return $self->{file} unless defined $self->{dir};
-  return $self->_spec->catfile($self->{dir}, $self->{file});
+  return $self->_spec->catfile($self->{dir}->stringify, $self->{file});
 }
 
 sub dir {
@@ -49,6 +52,10 @@ sub volume {
   return $self->{dir}->volume;
 }
 
+sub open  { IO::File->new(@_) }
+sub stat  { File::stat::stat("$_[0]") }
+sub lstat { File::stat::lstat("$_[0]") }
+
 1;
 __END__
 
@@ -186,6 +193,22 @@ there is a subclass of C<File::Spec>.
 The arguments in C<@args> are the same as they would be specified in
 C<new()>.
 
+=item $fh = $file->open($mode, $permissions)
+
+Passes the given arguments, including C<$file>, to C<< IO::File->open
+>> and returns the result as an C<IO::File> object.  If the opening
+fails, C<undef> is returned and C<$!> is set.
+
+=item $st = $file->stat()
+
+Invokes C<< File::stat::stat() >> on this file and returns a
+C<File::stat> object representing the result.
+
+=item $st = $file->lstat()
+
+Same as C<stat()>, but if C<$file> is a symbolic link, C<lstat()>
+stats the link instead of the file the link points to.
+
 =back
 
 =head1 AUTHOR
